@@ -6,7 +6,7 @@ use warnings;
 use base qw/Catalyst::Controller CGI::Expand/;
 
 __PACKAGE__->mk_accessors(qw(
-  class create_requires update_requires update_allows $self->rs_stash_key create_allows list_returns rs_stash_key object_stash_key
+  class create_requires update_requires update_allows $self->rs_stash_key create_allows list_count list_returns list_grouped_by list_ordered_by rs_stash_key object_stash_key setup_list_method
 ));
 
 __PACKAGE__->config(
@@ -16,6 +16,9 @@ __PACKAGE__->config(
   update_requires => [],
   update_allows => [],
   list_returns => [],
+  list_grouped_by => [],
+  list_ordered_by => [],
+  list_count => undef,
   object_stash_key => 'object',
   rs_stash_key => 'class_rs'
 );
@@ -29,20 +32,42 @@ sub setup :Chained('specify.in.subclass.config') :CaptureArgs(0) :PathPart('spec
 sub list :Private {
   my ($self, $c) = @_;
 
-  my $req_params = (grep { ref $_ } values %{$c->req->params}) ? $c->req->params : $self->expand_hash($c->req->params);
-  my $source = $c->stash->{$self->rs_stash_key}->result_source;
-  my @columns = (scalar(@{$self->list_returns})) ? @{$self->list_returns} : $source->columns;
+  my ($params, $args) = @{$c->forward('generate_dbic_search_args')};
 
-  my %search_params;
-  
-  my ($params, $join) = $self->_format_search({ params => $req_params->{search}, source => $source }) if ($req_params->{search});
-
-#  use Data::Dumper; warn Dumper($params, $join);
-  $c->stash->{$self->rs_stash_key} = $c->stash->{$self->rs_stash_key}->search($params, { join => $join, select => \@columns });
+#  use Data::Dumper; warn Dumper($params, $args);
+  $c->stash->{$self->rs_stash_key} = $c->stash->{$self->rs_stash_key}->search($params, $args);
 
   $c->forward('format_list');
 }
 
+sub generate_dbic_search_args :Private {
+  my ($self, $c) = @_;
+
+  my $req_params = (grep { ref $_ } values %{$c->req->params}) ? $c->req->params : $self->expand_hash($c->req->params);
+
+  if ( my $a = $self->setup_list_method ) {
+    my $setup_action = $self->action_for($a);
+    if ( defined $setup_action ) {
+      $c->forward("/$setup_action", [ $req_params ]);
+    } else {
+      $c->log->error("setup_list_method was configured, but action $a not found");
+    }
+  }
+
+  my $source = $c->stash->{$self->rs_stash_key}->result_source;
+
+  my ($params, $join);
+  ($params, $join) = $self->_format_search({ params => $req_params->{search}, source => $source }) if ($req_params->{search});
+  my $args = {};
+  $args->{group_by} = $req_params->{list_grouped_by} || ((scalar(@{$self->list_grouped_by})) ? $self->list_grouped_by : undef);
+  $args->{order_by} = $req_params->{list_ordered_by} || ((scalar(@{$self->list_ordered_by})) ? $self->list_ordered_by : undef);
+  $args->{rows} = $req_params->{list_count} || $self->list_count;
+  $args->{select} = $req_params->{list_returns} || ((scalar(@{$self->list_returns})) ? $self->list_returns : undef);
+  $args->{join} = $join;
+
+  return [$params, $args];
+}
+
 sub _format_search {
 	my ($self, $p) = @_;
 	my $params = $p->{params};
@@ -54,7 +79,7 @@ sub _format_search {
 	foreach my $rel ($source->relationships) {
 		if (exists $params->{$rel}) {
 			my $rel_params;
-			($rel_params, $join->{$rel}) = $self->_format_search({ params => $params->{$rel}, source => $source->related_source($rel), base => $rel });					   
+			($rel_params, $join->{$rel}) = $self->_format_search({ params => $params->{$rel}, source => $source->related_source($rel), base => $rel });
 			%search_params = ( %search_params, %{$rel_params} );
 		}
 	}
@@ -72,8 +97,8 @@ sub format_list :Private {
 sub create :Private {
 	my ($self, $c) = @_;
 
-	unless (ref($self->create_requires) eq 'ARRAY') {
-		die "create_requires must be an arrayref in config";
+	unless (ref($c->stash->{create_requires} || $self->create_requires) eq 'ARRAY') {
+		die "create_requires must be an arrayref in config or stash";
 	}
 	unless ($c->stash->{$self->rs_stash_key}) {
 		die "class resultset not set";
@@ -92,8 +117,8 @@ sub update :Private {
 	$c->req->params($req_params);
 	return unless ($c->stash->{$self->object_stash_key});
 
-	unless (ref($self->update_allows) eq 'ARRAY') {
-		die "update_allows must be an arrayref in config";
+	unless (ref($c->stash->{update_allows} || $self->update_allows) eq 'ARRAY') {
+		die "update_allows must be an arrayref in config or stash";
 	}
 	unless ($c->stash->{$self->rs_stash_key}) {
 		die "class resultset not set";
@@ -116,9 +141,15 @@ sub validate_and_save_object {
 
 	my $params;
 	unless ($params = $self->validate($c, $object)) {
+        $c->log->debug("No value from validate, cowardly bailing out")
+            if $c->debug;
 		return;
 	}
 
+    if ( $c->debug ) {
+        $c->log->debug("Saving object: $object");
+        $c->log->_dump( $params );
+    }
 	return $self->save_object($c, $object, $params);
 }
 
@@ -127,8 +158,8 @@ sub validate {
 	my $params = $c->req->params;
 
 	my %values;
-	my %requires_map = map { $_ => 1 } @{($object->in_storage) ? [] : $self->create_requires};
-	my %allows_map = map { (ref $_) ? %{$_} : ($_ => 1) } (keys %requires_map, @{($object->in_storage) ? $self->update_allows : $self->create_allows});
+	my %requires_map = map { $_ => 1 } @{($object->in_storage) ? [] : $c->stash->{create_requires} || $self->create_requires};
+	my %allows_map = map { (ref $_) ? %{$_} : ($_ => 1) } (keys %requires_map, @{($object->in_storage) ? ($c->stash->{update_allows} || $self->update_allows) : ($c->stash->{create_allows} || $self->create_allows)});
 	
 #	use Data::Dumper; warn Dumper($params, \%requires_map, \%allows_map);
 	foreach my $key (keys %allows_map) {
@@ -217,7 +248,13 @@ sub end :Private {
 
 	# check for errors
 	my $default_status;
-	if ($self->get_errors($c)) {
+
+    # Check for errors caught elsewhere
+    if ( $c->res->status and $c->res->status != 200 ) {
+		$default_status = $c->res->status;
+		$c->stash->{response}->{success} = 'false';
+    }
+	elsif ($self->get_errors($c)) {
 		$c->stash->{response}->{messages} = $self->get_errors($c);
 		$c->stash->{response}->{success} = 'false';
 		$default_status = 400;
