@@ -86,6 +86,20 @@ Provides an endpoint to the functionality described in L<Catalyst::Controller::D
 
 =cut 
 
+sub begin :Private {
+	my ($self, $c) = @_;
+
+	$c->forward('deserialize');
+	$c->req->params($c->req->data);
+	$self->NEXT::begin($c);	
+}
+
+# from Catalyst::Action::Serialize
+sub deserialize :ActionClass('Deserialize') {
+	my ($self, $c) = @_;
+
+}
+
 sub object :Chained('setup') :CaptureArgs(1) :PathPart('id') {
 	my ($self, $c, $id) = @_;
 
